/// <reference types="node" />
import * as web3 from '@solana/web3.js';
import * as beet from '@metaplex-foundation/beet';
export declare enum MarketState {
    Uninitialized = 0,
    Created = 1,
    Active = 2,
    Ended = 3
}
export declare type MarketAccountDataArgs = {
    store: web3.PublicKey;
    sellingResource: web3.PublicKey;
    treasuryMint: web3.PublicKey;
    treasuryHolder: web3.PublicKey;
    treasuryOwner: web3.PublicKey;
    owner: web3.PublicKey;
    name: string;
    description: string;
    mutable: boolean;
    price: beet.bignum;
    piecesInOneWallet: beet.COption<beet.bignum>;
    startDate: beet.bignum;
    endDate: beet.COption<beet.bignum>;
    state: MarketState;
};
export declare class MarketAccountData {
    readonly store: web3.PublicKey;
    readonly sellingResource: web3.PublicKey;
    readonly treasuryMint: web3.PublicKey;
    readonly treasuryHolder: web3.PublicKey;
    readonly treasuryOwner: web3.PublicKey;
    readonly owner: web3.PublicKey;
    readonly name: string;
    readonly description: string;
    readonly mutable: boolean;
    readonly price: beet.bignum;
    readonly piecesInOneWallet: beet.COption<beet.bignum>;
    readonly startDate: beet.bignum;
    readonly endDate: beet.COption<beet.bignum>;
    readonly state: MarketState;
    private constructor();
    static get byteSize(): number;
    static fromArgs(args: MarketAccountDataArgs): MarketAccountData;
    static fromAccountInfo(accountInfo: web3.AccountInfo<Buffer>, offset?: number): [MarketAccountData, number];
    static getMinimumBalanceForRentExemption(connection: web3.Connection, commitment?: web3.Commitment): Promise<number>;
    static hasCorrectByteSize(buf: Buffer, offset?: number): boolean;
    static deserialize(buf: Buffer, offset?: number): [MarketAccountData, number];
    serialize(): [Buffer, number];
    pretty(): {
        store: string;
        sellingResource: string;
        treasuryMint: string;
        treasuryHolder: string;
        treasuryOwner: string;
        owner: string;
        name: string;
        description: string;
        mutable: boolean;
        price: beet.bignum;
        piecesInOneWallet: beet.bignum;
        startDate: beet.bignum;
        endDate: beet.bignum;
    };
}
