/// <reference types="node" />
import * as web3 from '@solana/web3.js';
import * as beet from '@metaplex-foundation/beet';
export declare const enum SellingResourceState {
    Uninitialized = 0,
    Created = 1,
    InUse = 2,
    Exhausted = 3,
    Stopped = 4
}
export declare type SellingResourceAccountDataArgs = {
    store: web3.PublicKey;
    owner: web3.PublicKey;
    resource: web3.PublicKey;
    vault: web3.PublicKey;
    vaultOwner: web3.PublicKey;
    supply: beet.bignum;
    maxSupply: beet.COption<beet.bignum>;
    state: SellingResourceState;
};
export declare class SellingResourceAccountData {
    readonly store: web3.PublicKey;
    readonly owner: web3.PublicKey;
    readonly resource: web3.PublicKey;
    readonly vault: web3.PublicKey;
    readonly vaultOwner: web3.PublicKey;
    readonly supply: beet.bignum;
    readonly maxSupply: beet.COption<beet.bignum>;
    readonly state: SellingResourceState;
    private constructor();
    static get byteSize(): number;
    static getMinimumBalanceForRentExemption(connection: web3.Connection, commitment?: web3.Commitment): Promise<number>;
    static hasCorrectByteSize(buf: Buffer, offset?: number): boolean;
    static fromArgs(args: SellingResourceAccountDataArgs): SellingResourceAccountData;
    static fromAccountInfo(accountInfo: web3.AccountInfo<Buffer>, offset?: number): [SellingResourceAccountData, number];
    static deserialize(buf: Buffer, offset?: number): [SellingResourceAccountData, number];
    serialize(): [Buffer, number];
    pretty(): {
        store: string;
        owner: string;
        resource: string;
        vault: string;
        vaultOwner: string;
        supply: beet.bignum;
        maxSupply: beet.bignum;
        state: SellingResourceState;
    };
}
