"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.mintNFT = void 0;
const web3_js_1 = require("@solana/web3.js");
const amman_1 = require("@metaplex-foundation/amman");
const mpl_token_metadata_1 = require("@metaplex-foundation/mpl-token-metadata");
const spl_token_1 = require("@solana/spl-token");
const assert_1 = require("assert");
const create_token_account_1 = require("../transactions/create-token-account");
const create_metadata_1 = require("./create-metadata");
const utils_1 = require("../../test/utils");
const URI = 'https://arweave.net/Rmg4pcIv-0FQ7M7X838p2r592Q4NU63Fj7o7XsvBHEE';
const NAME = 'test';
const SYMBOL = 'sym';
const SELLER_FEE_BASIS_POINTS = 10;
function mintNFT({ transactionHandler, payer, connection }) {
    return __awaiter(this, void 0, void 0, function* () {
        const { mint, createMintTx } = yield new amman_1.Actions(connection).createMintAccount(payer);
        const mintRes = yield transactionHandler.sendAndConfirmTransaction(createMintTx, [mint], amman_1.defaultSendOptions);
        (0, utils_1.addLabel)('create:mint', mint);
        (0, amman_1.assertConfirmedTransaction)(assert_1.strict, mintRes.txConfirmed);
        const { tokenAccount, createTokenTx } = yield (0, create_token_account_1.createTokenAccount)({
            payer,
            mint: mint.publicKey,
            connection,
        });
        createTokenTx.add(spl_token_1.Token.createMintToInstruction(new web3_js_1.PublicKey(spl_token_1.TOKEN_PROGRAM_ID), mint.publicKey, tokenAccount.publicKey, payer, [], 1));
        const associatedTokenAccountRes = yield transactionHandler.sendAndConfirmTransaction(createTokenTx, [tokenAccount], amman_1.defaultSendOptions);
        (0, utils_1.addLabel)('create:associated-token-account', mint);
        (0, amman_1.assertConfirmedTransaction)(assert_1.strict, associatedTokenAccountRes.txConfirmed);
        const initMetadataData = new mpl_token_metadata_1.MetadataDataData({
            uri: URI,
            name: NAME,
            symbol: SYMBOL,
            sellerFeeBasisPoints: SELLER_FEE_BASIS_POINTS,
            creators: null,
        });
        const { createTxDetails, metadata } = yield (0, create_metadata_1.createMetadata)({
            transactionHandler,
            publicKey: payer,
            editionMint: mint.publicKey,
            metadataData: initMetadataData,
        });
        (0, utils_1.addLabel)('create:metadata', metadata);
        (0, amman_1.assertConfirmedTransaction)(assert_1.strict, createTxDetails.txConfirmed);
        const metadataPDA = yield mpl_token_metadata_1.Metadata.getPDA(mint.publicKey);
        const [edition, editionBump] = yield web3_js_1.PublicKey.findProgramAddress([
            Buffer.from(mpl_token_metadata_1.MetadataProgram.PREFIX),
            mpl_token_metadata_1.MetadataProgram.PUBKEY.toBuffer(),
            new web3_js_1.PublicKey(mint.publicKey).toBuffer(),
            Buffer.from(mpl_token_metadata_1.MasterEdition.EDITION_PREFIX),
        ], mpl_token_metadata_1.MetadataProgram.PUBKEY);
        const masterEditionTx = new mpl_token_metadata_1.CreateMasterEdition({ feePayer: payer }, {
            edition,
            metadata: metadataPDA,
            updateAuthority: payer,
            mint: mint.publicKey,
            mintAuthority: payer,
        });
        const masterEditionRes = yield transactionHandler.sendAndConfirmTransaction(masterEditionTx, [], {
            skipPreflight: false,
        });
        (0, utils_1.addLabel)('create:master-edition', edition);
        (0, amman_1.assertConfirmedTransaction)(assert_1.strict, masterEditionRes.txConfirmed);
        return { tokenAccount, edition, editionBump, mint };
    });
}
exports.mintNFT = mintNFT;
//# sourceMappingURL=mint-nft.js.map