"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const tape_1 = __importDefault(require("tape"));
const web3_js_1 = require("@solana/web3.js");
const utils_1 = require("./utils");
const amman_1 = require("@metaplex-foundation/amman");
const utils_2 = require("./utils");
const mpl_membership_token_1 = require("../src/mpl-membership-token");
const create_store_1 = require("./transactions/create-store");
(0, utils_1.killStuckProcess)();
(0, tape_1.default)('create-store: success', (t) => __awaiter(void 0, void 0, void 0, function* () {
    const payer = web3_js_1.Keypair.generate();
    (0, utils_2.addLabel)('create:payer', payer);
    const connection = new web3_js_1.Connection(utils_1.connectionURL, 'confirmed');
    const transactionHandler = new amman_1.PayerTransactionHandler(connection, payer);
    yield (0, amman_1.airdrop)(connection, payer.publicKey, 2);
    const { store, transaction } = yield (0, create_store_1.createStoreTransaction)(payer, connection);
    const createStoreRes = yield transactionHandler.sendAndConfirmTransaction(transaction, [store], amman_1.defaultSendOptions);
    (0, utils_2.addLabel)('create:store', store);
    (0, utils_1.logDebug)(`store: ${store.publicKey}`);
    (0, utils_1.logDebug)(createStoreRes.txSummary.logMessages.join('\n'));
    (0, amman_1.assertConfirmedTransaction)(t, createStoreRes.txConfirmed);
}));
(0, tape_1.default)('create-store: bad name', (t) => __awaiter(void 0, void 0, void 0, function* () {
    const payer = web3_js_1.Keypair.generate();
    const store = web3_js_1.Keypair.generate();
    (0, utils_2.addLabel)('create:payer', payer);
    const connection = new web3_js_1.Connection(utils_1.connectionURL, 'confirmed');
    yield (0, amman_1.airdrop)(connection, payer.publicKey, 2);
    t.throws(() => (0, mpl_membership_token_1.createCreateStoreInstruction)({
        store: store.publicKey,
        admin: payer.publicKey,
    }, {
        name: 'izd5Pr9ltIAJL4ac8cYMUDlakSXNPnJPfR9awYq2',
        description: '',
    }));
}));
(0, tape_1.default)('create-store: bad description', (t) => __awaiter(void 0, void 0, void 0, function* () {
    const payer = web3_js_1.Keypair.generate();
    const store = web3_js_1.Keypair.generate();
    (0, utils_2.addLabel)('create:payer', payer);
    const connection = new web3_js_1.Connection(utils_1.connectionURL, 'confirmed');
    yield (0, amman_1.airdrop)(connection, payer.publicKey, 2);
    t.throws(() => (0, mpl_membership_token_1.createCreateStoreInstruction)({
        store: store.publicKey,
        admin: payer.publicKey,
    }, {
        name: 'izd5Pr9ltIAJL4ac8cYMUDlakSXNPnJPfR9awYq2',
        description: '',
    }));
}));
//# sourceMappingURL=create-store.test.js.map