"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const tape_1 = __importDefault(require("tape"));
const web3_js_1 = require("@solana/web3.js");
const utils_1 = require("./utils");
const amman_1 = require("@metaplex-foundation/amman");
const utils_2 = require("../src/utils");
const utils_3 = require("./utils");
const create_store_1 = require("./transactions/create-store");
const mint_nft_1 = require("./actions/mint-nft");
const init_selling_resouce_1 = require("./transactions/init-selling-resouce");
const create_token_account_1 = require("./transactions/create-token-account");
(0, utils_1.killStuckProcess)();
(0, tape_1.default)('init-selling-resource: success', (t) => __awaiter(void 0, void 0, void 0, function* () {
    const payer = web3_js_1.Keypair.generate();
    (0, utils_3.addLabel)('create:payer', payer);
    const connection = new web3_js_1.Connection(utils_1.connectionURL, 'confirmed');
    const transactionHandler = new amman_1.PayerTransactionHandler(connection, payer);
    yield (0, amman_1.airdrop)(connection, payer.publicKey, 2);
    const { store, transaction: createStoreTx } = yield (0, create_store_1.createStoreTransaction)(payer, connection);
    const createStoreRes = yield transactionHandler.sendAndConfirmTransaction(createStoreTx, [store], amman_1.defaultSendOptions);
    (0, utils_3.addLabel)('create:store', store);
    (0, amman_1.assertConfirmedTransaction)(t, createStoreRes.txConfirmed);
    const { edition: masterEdition, editionBump: masterEditionBump, tokenAccount: resourceToken, mint: resourceMint, } = yield (0, mint_nft_1.mintNFT)({
        transactionHandler,
        payer: payer.publicKey,
        connection,
    });
    (0, utils_3.logDebug)(`mint: ${resourceMint.publicKey}`);
    const [vaultOwner, vaultOwnerBump] = yield (0, utils_2.findVaultOwnerAddress)(resourceMint.publicKey, store.publicKey);
    const { tokenAccount: vault, createTokenTx: createVaultTx } = yield (0, create_token_account_1.createTokenAccount)({
        payer: payer.publicKey,
        mint: resourceMint.publicKey,
        connection,
        owner: vaultOwner,
    });
    const createVaultRes = yield transactionHandler.sendAndConfirmTransaction(createVaultTx, [vault], amman_1.defaultSendOptions);
    (0, utils_3.addLabel)('create:vault', vault);
    (0, amman_1.assertConfirmedTransaction)(t, createVaultRes.txConfirmed);
    const { initSellingResourceTx, sellingResource } = yield (0, init_selling_resouce_1.createInitSellingResourceTransaction)({
        payer,
        connection,
        store,
        masterEdition,
        masterEditionBump,
        resourceMint: resourceMint.publicKey,
        resourceToken: resourceToken.publicKey,
        vault,
        owner: vaultOwner,
        vaultOwnerBump,
        maxSupply: 100,
    });
    const initSellingResourceRes = yield transactionHandler.sendAndConfirmTransaction(initSellingResourceTx, [sellingResource, vault], amman_1.defaultSendOptions);
    (0, utils_3.addLabel)('create:selling-resource', sellingResource);
    (0, amman_1.assertConfirmedTransaction)(t, initSellingResourceRes.txConfirmed);
    (0, utils_3.logDebug)(`sellingResource: ${store.publicKey}`);
    (0, utils_3.logDebug)(initSellingResourceRes.txSummary.logMessages.join('\n'));
}));
//# sourceMappingURL=init-selling-resource.test.js.map